| beta2-class | R Documentation |
beta2-class is used to store the results of beta diversity analysis,
including results for drawing and comparing differences between groups.
Users can construct a beta2-class through calc_beta2,
which can then be connected to nem_plot to visualize the results.
metaA data frame storing basic elements for visualization.
resultA character of pairwise comparison results.
tempA character vector of the difference comparison.
The constructor, calc_beta2; Class for storing single factor beta
diversity analysis, beta-class; Visualization function,
nem_plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.