| calc_alpha | R Documentation |
The calc_alpha() is used to perform alpha diversity analysis and create
alpha-class. This function can be used to calculate various alpha
diversity indices such as Chao1, ACE, Shannon, Simpson,
etc.
calc_alpha(data, ...)
data |
An |
... |
Other parameters for |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_alpha <- nem |> calc_alpha()
A alpha-class for storing alpha diversity analysis results.
Other functions in this R package for data calculations:
calc_beta2, calc_compare, calc_compare2,
calc_beta, calc_nemindex, calc_funguild,
calc_funguild2, calc_mf, calc_mf2,
calc_ter, calc_ter2, calc_ef,
calc_ef2.
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_alpha <- nem |> calc_alpha()
show(nem_alpha)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.