| calc_compare | R Documentation |
The calc_compare is used for multiple comparisons between different
treatments and create compare-class. This function is only
applicable to single factor analysis, see calc_compare2 for a
two factor version of the function.
calc_compare(data, .group, y, method, ...)
data |
An |
.group |
Grouping variables (supports only two groups). |
y |
Dependent variable (numeric data). |
method |
The method of difference comparison. Such as |
... |
Other parameters for |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_compare <- nem |> calc_compare(.group = con_crop, y = pH, method = TTest)
An compare-class object.
Other functions in this R package for data calculations:
calc_beta, calc_beta2, calc_compare2,
calc_alpha, calc_nemindex, calc_funguild,
calc_funguild2, calc_mf, calc_mf2,
calc_ter, calc_ter2, calc_ef,
calc_ef2.
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_ttest <- nem |>
filter_name(meta, Treatments %in% c("CK", "C8")) |>
calc_compare(.group = Treatments, y = Mesorhabditis, method = TTest)
nem_ttest
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.