View source: R/calc_funguild.R
| calc_funguild | R Documentation |
The calc_funguild() is used for nematode food web analysis and generate
funguild-class.
calc_funguild(data, .group)
data |
A |
.group |
The group variable. |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_fun <- nem |> calc_funguild(con_crop)
A funguild-class object that stores the desired
visualization results.
Ferris, Howard, Tom Bongers, and Ron GM de Goede. "A framework for soil food web diagnostics: extension of the nematode faunal analysis concept." Applied soil ecology 18.1 (2001): 13-29.
Other functions in this R package for data calculations:
calc_beta2, calc_compare, calc_compare2,
calc_beta, calc_alpha, calc_nemindex,
calc_funguild2, calc_mf, calc_mf2,
calc_ter, calc_ter2, calc_ef,
calc_ef2.
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_index <- nem |> calc_nemindex() |> calc_funguild(Treatments)
nem_index
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.