View source: R/calc_funguild2.R
| calc_funguild2 | R Documentation |
The calc_funguild2() is used for nematode food web analysis and generate
funguild2-class.
calc_funguild2(data, .group1, .group2)
data |
A |
.group1 |
The group variable factor 1. |
.group2 |
The group variable factor 2. |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_fun <- nem |> calc_funguild2(con_crop, season)
A funguild2-class object that stores the desired
visualization results.
Ferris, Howard, Tom Bongers, and Ron GM de Goede. "A framework for soil food web diagnostics: extension of the nematode faunal analysis concept." Applied soil ecology 18.1 (2001): 13-29.
Other functions in this R package for data calculations:
calc_beta2, calc_compare, calc_compare2,
calc_beta, calc_alpha, calc_nemindex,
calc_funguild, calc_mf, calc_mf2,
calc_ter, calc_ter2, calc_ef,
calc_ef2.
nem <- read_nem(tab = easynem_example("nemtab1.csv"),
tax = easynem_example("nemtax1.csv"),
meta = easynem_example("nemmeta1.csv"))
nem_index <- nem |> calc_nemindex() |> calc_funguild2(con_crop, season)
nem_index
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.