| calc_lm | R Documentation |
The calc_lm() function is used for linear regression analysis of
easynem-class. Note: Both the horizontal and vertical coordinates of this
function must be continuous variables.
calc_lm(data, group, x, y, ...)
data |
An |
group |
The group variable. |
x |
X-axis. |
y |
Y-axis. |
... |
Other parameters of the |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_lm <- nem |> calc_lm(con_crop, x = SOC, y = pH)
Returns an lme-class object storing the results of a
linear regression analysis.
Other functions in this R package for data calculations:
calc_beta2, calc_compare, calc_compare2,
calc_beta, calc_alpha, calc_nemindex,
calc_funguild, calc_funguild2, calc_mf2,
calc_mf, calc_ter2, calc_ef,
calc_ef2, calc_lm2
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_index <- nem |>
calc_alpha() |>
calc_nemindex() |>
calc_lm(group = Treatments,
x = Chao1,
y = TotalBiomass)
nem_index
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.