| calc_mf2 | R Documentation |
Metabolic footprints quantify the amplitude of Carbon utilisation by different food web components. The point in the middle of a rhombus represents the intersection of EI and SI and length of vertical and horizontal axes of the rhombus corresponds to the footprints of enrichment and structure components respectively.
calc_mf2(data, .group1, .group2)
data |
A |
.group1 |
The group variable factor 1. |
.group2 |
The group variable factor 2. |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_fun <- nem |> calc_nemindex() |> calc_mf2(con_crop, season)
A mf2-class object that stores the desired
visualization results.
Ferris, Howard. "Form and function: metabolic footprints of nematodes in the soil food web." European Journal of Soil Biology 46.2 (2010): 97-104.
Other functions in this R package for data calculations:
calc_beta2, calc_compare, calc_compare2,
calc_beta, calc_alpha, calc_nemindex,
calc_funguild, calc_funguild2, calc_mf,
calc_ter, calc_ter2, calc_ef,
calc_ef2.
nem <- read_nem(tab = easynem_example("nemtab1.csv"),
tax = easynem_example("nemtax1.csv"),
meta = easynem_example("nemmeta1.csv"))
nem_index <- nem |> calc_nemindex() |> calc_mf2(con_crop, season)
nem_index
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.