| calc_ter | R Documentation |
The calc_ter() function is used to perform ternary analysis on nematode
feeding (Relative biomass of bacteria-feeding nematodes, fungi-feeding nematodes,
and herbivorous nematodes) or cp values (Relative abundance of cp1 nematodes,
cp2 nematodes, and cp3-5 nematodes).
calc_ter(data, .group)
data |
An |
.group |
The group variable. |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_ter <- nem |> calc_ter(con_crop)
A ter-class object that stores the desired
visualization results.
Goede, RGM de, T. Bongers, and C. H. Ettema. "Graphical presentation and interpretation of nematode community structure: cp triangles." (1993): 743-750.
Other functions in this R package for data calculations:
calc_beta2, calc_compare, calc_compare2,
calc_beta, calc_alpha, calc_nemindex,
calc_funguild, calc_funguild2, calc_mf2,
calc_mf, calc_ter2, calc_ef,
calc_ef2.
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_index <- nem |> calc_ter(Treatments)
nem_index
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.