| calc_ter2 | R Documentation |
The calc_ter2() function is used to perform ternary analysis on nematode
feeding (Relative biomass of bacteria-feeding nematodes, fungi-feeding nematodes,
and herbivorous nematodes) or cp values (Relative abundance of cp1 nematodes,
cp2 nematodes, and cp3-5 nematodes).
calc_ter2(data, .group1, .group2)
data |
An |
.group1 |
The group variable factor 1. |
.group2 |
The group variable factor 2. |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_ter <- nem |> calc_ter2(con_crop, season)
A ter2-class object that stores the desired visualization results.
Goede, RGM de, T. Bongers, and C. H. Ettema. "Graphical presentation and interpretation of nematode community structure: cp triangles." (1993): 743-750.
Other functions in this R package for data calculations:
calc_beta2, calc_compare, calc_compare2,
calc_beta, calc_alpha, calc_nemindex,
calc_funguild, calc_funguild2, calc_mf2,
calc_mf, calc_ter, calc_ef,
calc_ef2.
nem <- read_nem(tab = easynem_example("nemtab1.csv"),
tax = easynem_example("nemtax1.csv"),
meta = easynem_example("nemmeta1.csv"))
nem_index <- nem |> calc_ter2(con_crop, season)
nem_index
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.