| compare2-class | R Documentation |
compare2-class is used to store the results of multiple comparisons results,
including results for drawing and comparing differences between groups.
Users can construct a compare2-class through calc_compare2,
which can then be connected to nem_plot to visualize the results.
metaA data frame storing basic elements for visualization.
resultA data frame of multiple comparisons results.
tempA character vector of the difference comparison.
The constructor, calc_compare2; Class for storing single factor
multiple comparisons analysis, compare-class; Visualization function,
nem_plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.