easynem-class: The main experiment-level class for easynem data

easynem-classR Documentation

The main experiment-level class for easynem data

Description

Integrate the nematode abundance table, nematode classification table, and experimental design table into an easynem-class, which makes it easier to filter and manage nematode data, and easier to link to the nematode database and conduct subsequent analysis.

Details

Users can read data via read_nem or read_nem2. When there are missing slots in easynem, the system will issue a warning, but this will not affect subsequent analysis.

Slots

tab

A single object of nematode abundance table.

tax

A single object of nematode classification table.

meta

A single object of experimental design table.

See Also

The constructor, read_nem for reading csv files and read_nem2 for reading tibble type data.


easynem documentation built on Nov. 5, 2025, 7:39 p.m.