ef-class: A S4 class to store energy flow results (single factor)

ef-classR Documentation

A S4 class to store energy flow results (single factor)

Description

The ef-class is an extension of the easynem-class to store the results of nematode energy flow analysis.

Slots

result

A data frame for storing the results of energy flow analysis.

See Also

The constructor, calc_ef; Visualization function, nem_plot.


easynem documentation built on Nov. 5, 2025, 7:39 p.m.