funguild-class: Class for storing computational results of nematode...

funguild-classR Documentation

Class for storing computational results of nematode functional guild analysis (single factor)

Description

The funguild-class is used to store the results of nematode functional guild analysis.

Slots

result

A data frame of storing computational results of nematode functional guild analysis.

See Also

The constructor, calc_funguild; Visualization function, nem_plot.


easynem documentation built on Nov. 5, 2025, 7:39 p.m.