| funguild2-class | R Documentation |
The funguild2-class is used to store the results of nematode functional guild analysis.
resultA data frame of storing computational results of nematode functional guild analysis.
The constructor, calc_funguild2; Visualization function, nem_plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.