| lme-class | R Documentation |
The lme-class is used to store the results of linear regression analysis.
metaStores the data frame for plotting.
resultA data frame for storing the results of linear regression analysis.
The constructor, calc_lm; Visualization function, nem_plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.