mf2-class: A S4 class to store Metabolic footprints results (two-factor)

mf2-classR Documentation

A S4 class to store Metabolic footprints results (two-factor)

Description

The mf2-class is used to store the results of nematode metabolic footprints analysis.

Slots

result

A data frame for storing the results of metabolic footprinting analysis.

See Also

The constructor, calc_mf2; Visualization function, nem_plot.


easynem documentation built on Nov. 5, 2025, 7:39 p.m.