| nem_plot | R Documentation |
The nem_plot() is used to visualize the calculation results and is a
generalized function for multiple classes including beta-class,
beta2-class, compare-class, compare2-class,
ef-class, ef2-class, funguild-class,
funguild2-class, mf-class, mf2-class,
ter-class, ter2-class, etc.
nem_plot(object, ...)
object |
|
... |
Other parameters to be expanded. |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_plot <- nem |> calc_beta(pca, Treatments, method = "bray") |> nem_plot()
A plot object. Typically a ggplot object for most classes,
or a recordedplot object for ter-class and
ter2-class ternary plots.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.