| nem_plot,beta-method | R Documentation |
The nem_plot function is generalized to the beta-class
and is used to visualize the single-factor beta diversity results.
## S4 method for signature 'beta'
nem_plot(object, level = 0.6, type = 1, ...)
object |
A |
level |
Used to adjust the size of the confidence ellipse. Default
|
type |
Method used to adjust the display of scatter area. |
... |
Other parameters to be expanded. |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_plot <- nem |> calc_beta(pca, Treatments, method = "bray") |> nem_plot()
An gg or ggplot object.
The nem_plot() is used to visualize the calculation results and is a
generalized function for multiple classes including beta-class,
beta2-class, compare-class, compare2-class,
ef-class, ef2-class, funguild-class,
funguild2-class, mf-class, mf2-class,
ter-class, ter2-class, etc.
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_plot <- nem |>
calc_beta(pcoa, Treatments, method = "bray") |>
nem_plot(level = 0)
nem_plot
nem_plot <- nem |>
calc_beta(nmds, Treatments, method = "bray") |>
nem_plot(type = 2)
nem_plot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.