| nem_plot,compare2-method | R Documentation |
The nem_plot function is generalized to the compare2-class
and is used to visualize the results of two-factor multiple comparisons.
## S4 method for signature 'compare2'
nem_plot(object, type1 = 1, type2 = 1, add, ...)
object |
A |
type1 |
|
type2 |
|
add |
Add standard deviation or standard error (only used when drawing a bar plot). |
... |
Other parameters to be expanded. |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_plot <- nem |> calc_compare2(.group1 = con_crop, .group2 = season, y = pH, method = LSD) |> nem_plot()
An gg or ggplot object.
The nem_plot() is used to visualize the calculation results and is a
generalized function for multiple classes including beta-class,
beta2-class, compare-class, compare2-class,
ef-class, ef2-class, funguild-class,
funguild2-class, mf-class, mf2-class,
ter-class, ter2-class, etc.
nem <- read_nem(tab = easynem_example("nemtab1.csv"),
tax = easynem_example("nemtax1.csv"),
meta = easynem_example("nemmeta1.csv"))
nem_plot <- nem |> calc_compare2(.group1 = con_crop,
.group2 = season, y = pH, method = LSD2) |>
nem_plot(type2 = 2)
nem_plot
nem_plot <- nem |> calc_compare2(.group1 = con_crop,
.group2 = season, y = pH, method = HSD2) |>
nem_plot(type1 = 2, type2 = 2, add = "mean_sd")
nem_plot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.