| nem_plot,ef-method | R Documentation |
The nem_plot function is generalized to the ef-class
and is used to visualize the energy structure of nematode communities. a five-node
food web was constructed with bacterivores, fungivores and herbivores receiving
energy from basal resources (R), omnivores-carnivores receiving energy from other
nodes. Numbers along the lines represented energy flux (ug C / 100 g dry soil / day).
The size of nodes corresponds to the fresh biomass (ug / 100 g dry soil).
Uniformity (U) of soil nematode energetic structure (unitless, mean ± standard error)
was calculated as the ratio of the mean of summed energy flux through each
energy channel to the standard deviation of these mean values.
## S4 method for signature 'ef'
nem_plot(object)
object |
A |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_plot <- nem |> calc_nemindex() |> calc_ef(Treatments) |> nem_plot()
An gg or ggplot object.
Wan, Bingbing, et al. "Organic amendments increase the flow uniformity of energy across nematode food webs." Soil Biology and Biochemistry 170 (2022): 108695.
Ferris, H., 2010. Form and function: metabolic footprints of nematodes in the soil food web. European Journal of Soil Biology 46, 97–104.
Van Den Hoogen, Johan, et al. "Soil nematode abundance and functional group composition at a global scale." Nature 572.7768 (2019): 194-198.
Barnes, A.D., Jochum, M., Mumme, S., Haneda, N.F., Farajallah, A., Widarto, T.H., Brose, U., 2014. Consequences of tropical land use for multitrophic biodiversity and ecosystem functioning. Nature Communications 5, 1–7.
De Ruiter, P.C., Van Veen, J.A., Moore, J.C., Brussaard, L., Hunt, H.W., 1993. Calculation of nitrogen mineralization in soil food webs. Plant and Soil 157, 263–273.
The nem_plot() is used to visualize the calculation results and is a
generalized function for multiple classes including beta-class,
beta2-class, compare-class, compare2-class,
ef-class, ef2-class, funguild-class,
funguild2-class, mf-class, mf2-class,
ter-class, ter2-class, etc.
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_plot <- nem |>
calc_nemindex() |>
calc_ef(Treatments) |>
nem_plot()
nem_plot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.