| nem_plot,funguild-method | R Documentation |
The nem_plot function is generalized to the funguild-class
and is used to visualize the nematode functional guild data.
## S4 method for signature 'funguild'
nem_plot(object)
object |
A |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_plot <- nem |> calc_nemindex() |> calc_funguild(Treatments) |> nem_plot()
An gg or ggplot object.
The nem_plot() is used to visualize the calculation results and is a
generalized function for multiple classes including beta-class,
beta2-class, compare-class, compare2-class,
ef-class, ef2-class, funguild-class,
funguild2-class, mf-class, mf2-class,
ter-class, ter2-class, etc.
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_plot <- nem |>
calc_nemindex() |>
calc_funguild(Treatments) |>
nem_plot()
nem_plot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.