nem_plot-funguild2-method: Visualizing nematode functional guild data (two-factor)

nem_plot,funguild2-methodR Documentation

Visualizing nematode functional guild data (two-factor)

Description

The nem_plot function is generalized to the funguild2-class and is used to visualize the nematode functional guild data.

Usage

## S4 method for signature 'funguild2'
nem_plot(object)

Arguments

object

A funguild2-class object.

Details

To facilitate code interpretation, it is recommended to use the pipe symbol |> to connect functions:

nem_plot <- nem |> calc_nemindex() |> calc_funguild2(con_crop, season) |> nem_plot()

Value

An gg or ggplot object.

See Also

The nem_plot() is used to visualize the calculation results and is a generalized function for multiple classes including beta-class, beta2-class, compare-class, compare2-class, ef-class, ef2-class, funguild-class, funguild2-class, mf-class, mf2-class, ter-class, ter2-class, etc.

Examples

nem <- read_nem(tab = easynem_example("nemtab1.csv"),
                tax = easynem_example("nemtax1.csv"),
                meta = easynem_example("nemmeta1.csv"))
nem_plot <- nem |>
            calc_nemindex() |>
            calc_funguild2(con_crop, season) |>
            nem_plot()
nem_plot

easynem documentation built on Nov. 5, 2025, 7:39 p.m.