nem_plot-lme2-method: Visualizing the results of linear regression (two-factor)

nem_plot,lme2-methodR Documentation

Visualizing the results of linear regression (two-factor)

Description

The nem_plot function is generalized to the lme2-class and is used to visualize the results of linear regression.

Usage

## S4 method for signature 'lme2'
nem_plot(object, ...)

Arguments

object

A lme2-class object.

...

Other parameters of stat_cor function.

Details

To facilitate code interpretation, it is recommended to use the pipe symbol |> to connect functions:

nem_plot <- nem |> calc_lm2(con_crop, season, x = SOC, y = pH) |> nem_plot()

Value

An gg or ggplot object.

See Also

The nem_plot() is used to visualize the calculation results and is a generalized function for multiple classes including beta-class, beta2-class, compare-class, compare2-class, ef-class, ef2-class, funguild-class, funguild2-class, mf-class, mf2-class, ter-class, ter2-class, etc.

Examples

nem <- read_nem(tab = easynem_example("nemtab1.csv"),
                tax = easynem_example("nemtax1.csv"),
                meta = easynem_example("nemmeta1.csv"))
nem_lm <- nem |> calc_lm2(con_crop, season, x = pH, y = Fe) |> nem_plot()
nem_lm

easynem documentation built on Nov. 5, 2025, 7:39 p.m.