nem_plot-mf2-method: Visualizing the metabolic footprint of nematode communities...

nem_plot,mf2-methodR Documentation

Visualizing the metabolic footprint of nematode communities (two-factor)

Description

The nem_plot function is generalized to the mf2-class and is used to visualize the metabolic footprint of nematode communities. Metabolic footprints quantify the amplitude of Carbon utilisation by different food web components. The point in the middle of a rhombus represents the intersection of EI and SI and length of vertical and horizontal axes of the rhombus corresponds to the footprints of enrichment and structure components respectively.

Usage

## S4 method for signature 'mf2'
nem_plot(object, kei = 1, ksi = 1)

Arguments

object

A mf2-class object.

kei

Adjust the width of the diamond, default kei = 1.

ksi

Adjust the length of the diamond, default ksi = 1.

Details

To facilitate code interpretation, it is recommended to use the pipe symbol |> to connect functions:

nem_plot <- nem |> calc_nemindex() |> calc_mf2(con_crop, season) |> nem_plot()

Value

An gg or ggplot object.

References

  • https://shiny.wur.nl/ninja/

  • Ferris, Howard. "Form and function: metabolic footprints of nematodes in the soil food web." European Journal of Soil Biology 46.2 (2010): 97-104.

See Also

The nem_plot() is used to visualize the calculation results and is a generalized function for multiple classes including beta-class, beta2-class, compare-class, compare2-class, ef-class, ef2-class, funguild-class, funguild2-class, mf-class, mf2-class, ter-class, ter2-class, etc.

Examples

nem <- read_nem(tab = easynem_example("nemtab1.csv"),
                tax = easynem_example("nemtax1.csv"),
                meta = easynem_example("nemmeta1.csv"))
nem_plot <- nem |>
            calc_nemindex() |>
            calc_mf2(con_crop, season) |>
            nem_plot(kei = 35, ksi = 35)
nem_plot

easynem documentation built on Nov. 5, 2025, 7:39 p.m.