| nem_plot,ter2-method | R Documentation |
The nem_plot function is generalized to the ter2-class
and is used to visualize the results of the ternary analysis. This function
visualizes the distribution of nematode communities using the relative abundance
of nematodes of cp1, cp2, and cp3-5 or the relative biomass
of herbivorous nematodes, bacterivorous nematodes, and fungivorous nematodes
as the three axes of a ternary plot.
## S4 method for signature 'ter2'
nem_plot(object, type, point_size = 1, legend_cex = 0.9, ...)
object |
A |
type |
Visualize the nematodes by their |
point_size |
Size of the points. Default is 1. |
legend_cex |
Size of the legend text. Default is 0.9 |
... |
Additional parameters passed to |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_plot <- nem |> calc_ter2(con_crop, season) |> nem_plot()
A recordedplot object from Ternary::TernaryPlot.
Goede, RGM de, T. Bongers, and C. H. Ettema. "Graphical presentation and interpretation of nematode community structure: cp triangles." (1993): 743-750.
The nem_plot() is used to visualize the calculation results and is a
generalized function for multiple classes including beta-class,
beta2-class, compare-class, compare2-class,
ef-class, ef2-class, funguild-class,
funguild2-class, mf-class, mf2-class,
ter-class, ter2-class, etc.
nem <- read_nem(tab = easynem_example("nemtab1.csv"),
tax = easynem_example("nemtax1.csv"),
meta = easynem_example("nemmeta1.csv"))
nem_plot <- nem |>
calc_ter2(con_crop, season) |>
nem_plot(type = feeding)
nem_plot
nem_plot <- nem |>
calc_ter2(con_crop, season) |>
nem_plot(type = cp)
nem_plot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.