| read_nem | R Documentation |
read_nem() is a constructor method. This is the main method suggested
for constructing an experiment-level (easynem-class) object
from its component data (component data: tab, tax, meta).
read_nem(tab = 0, tax = 0, meta = 0, ...)
tab |
Nematode abundance table. |
tax |
Nematode abundance table. |
meta |
Experimental design table. |
... |
Other default parameters for |
An easynem object. The components in the class are interconnected to facilitate the subsequent screening and management of nematode data. When this class is generated, it will automatically check whether there is nematode information in the species classification table. If not, it will not be associated with the nematode database.
read_nem2
easynem <- read_nem(tab = easynem_example("nemtab.csv"),
tax = easynem_example("nemtax.csv"),
meta = easynem_example("nemmeta.csv"))
show(easynem)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.