read_nem2: Build easynem-class objects from their tibble type object

View source: R/read_nem2.R

read_nem2R Documentation

Build easynem-class objects from their tibble type object

Description

read_nem2() is a constructor method. This is the main method suggested for constructing an experiment-level (easynem-class) object from its tibble type object (component data: tab, tax, meta).

Usage

read_nem2(tab = 0, tax = 0, meta = 0, ...)

Arguments

tab

Nematode abundance table.

tax

Nematode abundance table.

meta

Experimental design table.

...

Other default parameters for read_csv function.

Value

An easynem object. The components in the class are interconnected to facilitate the subsequent screening and management of nematode data. When this class is generated, it will automatically check whether there is nematode information in the species classification table. If not, it will not be associated with the nematode database.

See Also

read_nem

Examples

easynem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
show(easynem)

easynem documentation built on Nov. 5, 2025, 7:39 p.m.