ter-class: A S4 class to store the ternary analysis results (single...

ter-classR Documentation

A S4 class to store the ternary analysis results (single factor)

Description

The ter-class is used to store the results of nematode ternary analysis.

Slots

result

A data frame for storing the results of ternary analysis.

See Also

The constructor, calc_ter; Visualization function, nem_plot.


easynem documentation built on Nov. 5, 2025, 7:39 p.m.