| trans_name | R Documentation |
The trans_name() is used to re-summarize the nematode abundance table
by nematode taxonomy table.
trans_name(data, taxonomy)
data |
An |
taxonomy |
Nematode taxonomic name or other nematode attributes. |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_trans <- nem |> trans_name(Family)
A reclassified and aggregated easynem-class.
Since the nematode taxonomy table is automatically associated with the nematode
database (nem_database) including feeding and cp_value
when reading data through read_nem or read_nem2,
feeding can also be passed as a parameter to trans_name(). The
corresponding relationship between the feeding value and the actual nematode
feeding habits is as follows:
feeding = 1, plant feeding
feeding = 2, fungal hyphal feeding
feeding = 3, bacterial feeding
feeding = 4, substrate ingestion
feeding = 5, predation (including specialist predators of nematodes)
feeding = 6, eucaryote feeding
feeding = 7, dispersal stages or animal parasites
feeding = 8, omnivory (including general predators of nematodes)
Other functions in this package for filtering and transforming data sets:
filter_name, trans_formula, trans_formula_v,
filter_num, trans_norm, trans_rare,
trans_combine
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_trans <- nem |> trans_name(Family)
show(nem_trans)
nem_trans <- nem |> trans_name(feeding)
show(nem_trans)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.