| trans_norm | R Documentation |
The trans_norm() is an extension of the decostand
function of the vegan package for easynem-class data, which is
used to standardize the nematode abundance table to reduce the order of magnitude
differences of nematodes in each treatment.
trans_norm(data, method, MARGIN = 2, ...)
data |
An |
method |
Standardization method. For details, refer to the
|
MARGIN |
Margin, |
... |
Other parameters of the |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_trans <- nem |> trans_norm(method = total)
A normalized easynem-class data.
Other functions in this package for filtering and transforming data sets:
filter_name, trans_formula, trans_formula_v,
trans_name, filter_num, trans_rare,
trans_combine
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_trans <- nem |> trans_norm(method = total)
colSums(nem_trans@tab[,-1])
nem_trans <- nem |> trans_norm(method = percent)
colSums(nem_trans@tab[,-1])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.