| trans_rare | R Documentation |
The trans_rare() is an extension of the rrarefy
function of the vegan package for easynem-class data, which is
used to randomly rarefied OTU or ASV tables of nematodes for amplicon sequencing
data. The default is to rare according to the minimum abundance of nematode
in each treatment.
trans_rare(data, sample = 0, ...)
data |
An |
sample |
Subsample size for rarefying community. The default |
... |
Other parameters of the |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_trans <- nem |> trans_rare(1500)
A rarefied easynem-class data.
Other functions in this package for filtering and transforming data sets:
filter_name, trans_formula, trans_formula_v,
trans_name, filter_num, trans_norm,
trans_combine
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_trans <- nem |> trans_rare()
colSums(nem_trans@tab[,-1])
nem_trans <- nem |> trans_rare(1500)
colSums(nem_trans@tab[,-1])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.