| calc_beta | R Documentation |
The calc_beta() is used to perform beta diversity analysis and create
beta-class. This function is only applicable to single factor
analysis, see calc_beta2 for a two-factor version of the
function.
calc_beta(data, type, .group, method, ...)
data |
An |
type |
Types of beta diversity analysis ( |
.group |
Treatment factors that need to be compared. |
method |
Dissimilarity index, partial match to |
... |
Other parameters for |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_pca <- nem |> calc_beta(pca, Treatments, method = "bray")
A beta-class for storing beta diversity analysis results.
Other functions in this R package for data calculations:
calc_beta2, calc_compare, calc_compare2,
calc_alpha, calc_nemindex, calc_funguild,
calc_funguild2, calc_mf, calc_mf2,
calc_ter, calc_ter2, calc_ef,
calc_ef2.
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_pcoa <- nem |> calc_beta(pcoa, Treatments, method = "bray")
show(nem_pcoa)
nem_nmds <- nem |> calc_beta(nmds, Treatments, method = "bray")
show(nem_nmds)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.