| easynem-class | R Documentation |
Integrate the nematode abundance table, nematode classification table, and
experimental design table into an easynem-class, which makes it easier to
filter and manage nematode data, and easier to link to the nematode database
and conduct subsequent analysis.
Users can read data via read_nem or read_nem2.
When there are missing slots in easynem, the system will issue a warning, but
this will not affect subsequent analysis.
tabA single object of nematode abundance table.
taxA single object of nematode classification table.
metaA single object of experimental design table.
The constructor, read_nem for reading csv files and
read_nem2 for reading tibble type data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.