| filter_name | R Documentation |
The filter_name() is the extension of the filter
function for easynem type data, used to subset an easynem object, retaining
all rows that satisfy your conditions. This function selects one of tab,
tax or meta in easynem for filtering. When any of the three
components changes, the related components will also change accordingly. To be
retained, the row must produce a value of TRUE for all conditions.
filter_name(data, target, ...)
data |
An |
target |
|
... |
Other parameters of the |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_filter <- nem |> filter_name(target = meta, season == "Summer")
An easynem-class data. The rows of each component are a
subset of the input, but appear in the same order and the columns of each
component are not modified.
Other functions in this package for filtering and transforming data sets:
filter_num, trans_formula, trans_formula_v,
trans_name, trans_norm, trans_rare,
trans_combine
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_filter <- nem |> filter_name(target = meta, Treatments == "C4")
show(nem_filter)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.