| nem_plot,compare-method | R Documentation |
The nem_plot function is generalized to the compare-class
and is used to visualize the results of single-factor multiple comparisons.
## S4 method for signature 'compare'
nem_plot(object, type = 1, add, ...)
object |
A |
type |
|
add |
Add standard deviation or standard error (only used when drawing a bar plot). |
... |
Other parameters to be expanded. |
To facilitate code interpretation, it is recommended to use the pipe symbol
|> to connect functions:
nem_plot <- nem |> calc_compare(.group = con_crop, y = pH, method = LSD) |> nem_plot()
An gg or ggplot object.
The nem_plot() is used to visualize the calculation results and is a
generalized function for multiple classes including beta-class,
beta2-class, compare-class, compare2-class,
ef-class, ef2-class, funguild-class,
funguild2-class, mf-class, mf2-class,
ter-class, ter2-class, etc.
nem <- read_nem2(tab = nemtab, tax = nemtax, meta = nemmeta)
nem_plot <- nem |> calc_compare(.group = Treatments,
y = Mesorhabditis,
method = LSD) |>
nem_plot()
nem_plot
nem_plot <- nem |> calc_compare(.group = Treatments,
y = Mesorhabditis,
method = HSD) |>
nem_plot(type = 2, add = "mean_se")
nem_plot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.